@@ -66,7 +66,7 @@ def setup_logging(
     # noti
     class NotiFormatter(logging.Formatter):
         def format(self, record):
-            if(record.args and 'noti' in record.args.keys()):
+            if(record.args and isinstance(record.args, dict) and 'noti' in record.args.keys()):
                 noti = record.args.get("noti")
                 record.noti_status = "NOTI" if noti else 'NOT_NOTI'
             else:
@@ -88,7 +88,7 @@ def setup_logging(
     # _add_logger_level('NOTI', logging.WARNING + 5) # user info and force
     # noti instead
 
-    # set log level
+    # set log level ()
 
 
 def setup_logging_dec(*args,
@@ -115,7 +115,7 @@ def setup_logging_dec(*args,
                 default_noti_level=default_noti_level,
                 force_noti_level=force_noti_level)
             try:
-                func(*args, **kwargs)
+                return func(*args, **kwargs)
             except Exception as e:
                 if lambda_exec_error_log:
                     logging.critical(str(e), exc_info=True)
